@@ -1,4 +1,5 @@
 import abc
+import json
 import warnings
 from dataclasses import dataclass
 from functools import partial
@@ -13,10 +14,12 @@ from typing import (
     Optional,
     Type,
     TypeVar,
+    Union,
     cast,
 )
 
 from pydantic import BaseModel, Field
+from pydantic.json import ENCODERS_BY_TYPE
 from result import Result
 from result.result import F, U
 
@@ -37,7 +40,7 @@ from ...typing import (
     ResourceName,
     Url,
 )
-from .http import HTTPRequest, HTTPResponse, Links
+from .http import HTTPRequest, HTTPResponse, Links, simpletypes
 
 PATH: HttpLocation = "path"
 HEADER: HttpLocation = "headers"
@@ -55,6 +58,39 @@ PostBodyField = partial(Field, location=BODY)
 """Declare field that are serialized in the json document."""
 
 
+class JSONEncoder(json.JSONEncoder):
+    def default(self, o: Any) -> Any:
+        for typ, serializer in ENCODERS_BY_TYPE.items():
+            if isinstance(o, typ):
+                return serializer(o)
+        return super(JSONEncoder, self).default(o)
+
+
+def serialize_part(req: "Request", part: Dict[IntStr, Any]) -> Dict[str, simpletypes]:
+    return cast(
+        Dict[str, simpletypes],
+        {
+            **{
+                k: v
+                for k, v in req.dict(
+                    include=part,
+                    by_alias=True,
+                    exclude_none=True,
+                    exclude_defaults=False,
+                ).items()
+                if v is not None
+            },
+            **req.dict(
+                include=part,
+                by_alias=True,
+                exclude_none=False,
+                exclude_unset=True,
+                exclude_defaults=False,
+            ),
+        },
+    )
+
+
 class Request(BaseModel):
     """
     Request Params Model.
@@ -81,18 +117,15 @@ class Request(BaseModel):
             )
             fields_by_loc[loc].update({field.name: ...})
 
-        headers = self.dict(
-            include=fields_by_loc[HEADER], by_alias=True, exclude_none=True
-        )
+        headers = serialize_part(self, fields_by_loc[HEADER])
         req.headers = {key: str(val) for key, val in headers.items()}
-        req.path = self.dict(
-            include=fields_by_loc[PATH], by_alias=True, exclude_none=False
+        req.path = serialize_part(self, fields_by_loc[PATH])
+        req.querystring = cast(
+            Dict[str, Union[simpletypes, List[simpletypes]]],
+            serialize_part(self, fields_by_loc[QUERY]),
         )
-        req.querystring = self.dict(
-            include=fields_by_loc[QUERY], by_alias=True, exclude_none=True
-        )
-        req.body = self.json(
-            include=fields_by_loc[BODY], by_alias=True, exclude_none=False
+        req.body = json.dumps(
+            serialize_part(self, fields_by_loc[BODY]), cls=JSONEncoder
         )
         return req
 
