@@ -7,7 +7,7 @@ from typing import Mapping, MutableMapping, Optional, Tuple, Type
 
 from blacksmith.typing import (
     ClientName,
-    HttpMethod,
+    HTTPMethod,
     Path,
     ResourceName,
     Service,
@@ -19,7 +19,7 @@ from .exceptions import ConfigurationError, UnregisteredClientException
 from .model import AbstractCollectionParser, Request, Response
 
 Schemas = Tuple[Type[Request], Optional[Type[Response]]]
-Contract = Mapping[HttpMethod, Schemas]
+Contract = Mapping[HTTPMethod, Schemas]
 
 
 @dataclass(frozen=True)
@@ -91,7 +91,7 @@ class Registry:
         collection_path: Optional[Path] = None,
         collection_contract: Optional[Contract] = None,
         collection_parser: Optional[Type[AbstractCollectionParser]] = None,
-    ):
+    ) -> None:
         """
         Register the resource in the registry.
 
@@ -150,7 +150,7 @@ def register(
     collection_path: Optional[Path] = None,
     collection_contract: Optional[Contract] = None,
     collection_parser: Optional[Type[AbstractCollectionParser]] = None,
-):
+) -> None:
     """
     Register a resource in a client in the default registry.
 
