@@ -1,24 +1,28 @@
 from typing import Dict
 
-from blacksmith.domain.model.http import HTTPRequest, HTTPResponse
+from blacksmith.domain.model.http import HTTPRequest, HTTPResponse, HTTPTimeout
 from blacksmith.domain.typing import AsyncMiddleware
-from blacksmith.typing import ClientName, HttpMethod, Path
+from blacksmith.typing import ClientName, Path
 
 
 class AsyncHTTPMiddleware:
     """Inject data in http query on every requests."""
 
-    def __init__(self) -> None:
-        pass
+    async def initialize(self) -> None:
+        """
+        Asynchronous initialization of a middleware.
 
-    async def initialize(self):
-        pass
+        For instance, used to initialize connection to storage backend.
+        """
 
     def __call__(self, next: AsyncMiddleware) -> AsyncMiddleware:
         async def handle(
-            req: HTTPRequest, method: HttpMethod, client_name: ClientName, path: Path
+            req: HTTPRequest,
+            client_name: ClientName,
+            path: Path,
+            timeout: HTTPTimeout,
         ) -> HTTPResponse:
-            return await next(req, method, client_name, path)
+            return await next(req, client_name, path, timeout)
 
         return handle
 
@@ -37,9 +41,12 @@ class AsyncHTTPAddHeadersMiddleware(AsyncHTTPMiddleware):
 
     def __call__(self, next: AsyncMiddleware) -> AsyncMiddleware:
         async def handle(
-            req: HTTPRequest, method: HttpMethod, client_name: ClientName, path: Path
+            req: HTTPRequest,
+            client_name: ClientName,
+            path: Path,
+            timeout: HTTPTimeout,
         ) -> HTTPResponse:
             req.headers.update(self.headers)
-            return await next(req, method, client_name, path)
+            return await next(req, client_name, path, timeout)
 
         return handle
